pub struct FulfillmentPreviewItem {
    pub seller_sku: String,
    pub quantity: i32,
    pub seller_fulfillment_order_item_id: String,
    pub estimated_shipping_weight: Option<Box<Weight>>,
    pub shipping_weight_calculation_method: Option<ShippingWeightCalculationMethod>,
}
FulfillmentPreviewItem : Item information for a shipment in a fulfillment order preview.

Fields

seller_sku: String

The seller SKU of the item.

quantity: i32

The item quantity.

seller_fulfillment_order_item_id: String

A fulfillment order item identifier that the seller created with a call to the createFulfillmentOrder operation.

estimated_shipping_weight: Option<Box<Weight>>shipping_weight_calculation_method: Option<ShippingWeightCalculationMethod>

The method used to calculate the estimated shipping weight.

Implementations

Item information for a shipment in a fulfillment order preview.