Struct amazon_sp_fulfillment_outbound::models::fulfillment_preview_item::FulfillmentPreviewItem
source · [−]pub struct FulfillmentPreviewItem {
pub seller_sku: String,
pub quantity: i32,
pub seller_fulfillment_order_item_id: String,
pub estimated_shipping_weight: Option<Box<Weight>>,
pub shipping_weight_calculation_method: Option<ShippingWeightCalculationMethod>,
}Expand description
FulfillmentPreviewItem : Item information for a shipment in a fulfillment order preview.
Fields
seller_sku: StringThe seller SKU of the item.
quantity: i32The item quantity.
seller_fulfillment_order_item_id: StringA fulfillment order item identifier that the seller created with a call to the createFulfillmentOrder operation.
estimated_shipping_weight: Option<Box<Weight>>shipping_weight_calculation_method: Option<ShippingWeightCalculationMethod>The method used to calculate the estimated shipping weight.
Implementations